import { request } from '@/utils/request';
import type {
  IGetSelectTemplateReq,
  IGetSelectTemplateRes,
  IICDListRes
} from '@/types/prescript/TTemplate';
import { TPageData } from '@/types/Request';

/** 获取模版下拉选项 */
const getSelectTemplate = (params: IGetSelectTemplateReq) =>
  request<IGetSelectTemplateRes[]>(
    '/prescription-comment/publicController/getSelectTemplate',
    'get',
    params
  );

/** 根据模板id 获取模板详情 */
const getCfdpCommentInfo = (params: { id: string }) =>
  request(
    '/prescription-comment/publicController/getCfdpCommentInfo',
    'get',
    params
  );

/** 查询ICD诊断 */
interface IGetMdmIcdListReq {
  /** 查询条件 名称/拼音码/五笔码/编码 */
  condition: string;
  /** 页数 */
  pageNum: number;
  /** 条数 */
  pageSize: number;
}
const getMdmIcdList = (data: IGetMdmIcdListReq) =>
  request<TPageData<Array<IICDListRes>>>(
    '/prescription-comment/publicController/getMdmIcdList',
    'post',
    data
  );

/** 获取药品列表 */
interface IGetDrugNameListReq {
  /** 查询条件 名称/拼音码/五笔码/编码 */
  keyword: string;
  /** 页数 */
  pageNum: number;
  /** 条数 */
  pageSize: number;
}
const getDrugNameList = (data: IGetDrugNameListReq) =>
  request(
    '/prescription-comment/publicController/getDrugNameList',
    'post',
    data,
    {
      'Content-Type': 'multipart/form-data'
    }
  );

/** 获取点评专家列表 */
interface IGetRoleUserListReq {
  /** 查询条件 名称/拼音码/五笔码/编码 */
  userName: string;
  /** 页数 */
  pageNumber: number;
  /** 条数 */
  pageSize: number;
}
const getRoleUserList = (data: IGetRoleUserListReq) =>
  request<TPageData<any>>(
    '/prescription-comment/publicController/getRoleUserList',
    'post',
    data
  );

export default {
  getSelectTemplate,
  getMdmIcdList,
  getDrugNameList,
  getRoleUserList,
  getCfdpCommentInfo
};
